==> xcpcio_board_spider-0.0.1-py3-none-any.whl: xcpcio_board_spider/utils.py <==
import json
import time
import os


def hello_world():
    return "hello world"


def json_input(path):
    with open(path, 'r') as f:
        return json.load(f)


def json_output(data):
    return json.dumps(data, sort_keys=False, separators=(',', ':'), ensure_ascii=False)


def output(target_path, data, if_not_exists=False):
    if if_not_exists and os.path.exists(target_path):
        return

    with open(target_path, 'w') as f:
        f.write(json_output(data))


def mkdir(_path):
    if not os.path.exists(_path):
        os.makedirs(_path)


def get_timestamp(dt):
    timeArray = time.strptime(dt, "%Y-%m-%d %H:%M:%S")
    timestamp = time.mktime(timeArray)
    return int(timestamp)


def url_to_base64(url):
    import base64
    import requests as req
    from io import BytesIO

    if os.path.isfile(url):
        f = open(url, 'rb')
        img_data_b64 = base64.b64encode(f.read())
        f.close()
    else:
        response = req.get(url)
        img_data_b64 = base64.b64encode(BytesIO(response.content).read())

    return bytes.decode(img_data_b64)


def get_cookies(raw_cookies: str):
    from http.cookies import SimpleCookie
    cookie = SimpleCookie()
    cookie.load(raw_cookies)

    # Even though SimpleCookie is dictionary-like, it internally uses a Morsel object
    # which is incompatible with requests. Manually construct a dictionary instead.
    cookies = {k: v.value for k, v in cookie.items()}

    return cookies


def read_xls(xls_file_path: str):
    import xlrd
    data = xlrd.open_workbook(xls_file_path)
    table = data.sheets()[0]
    nrows = table.nrows

    for i in range(1, nrows):
        yield table.row_values(i)


def frozen_fallback(runs, frozen_start_timestamp):
    for r in runs:
        if r['timestamp'] >= frozen_start_timestamp:
            r['status'] = 'pending'

    return runs

==> xcpcio_board_spider-0.0.5-py3-none-any.whl: xcpcio_board_spider/utils.py <==
import json
import time
import os
import typing

from . import config


def json_input(path: str) -> None:
    with open(path, 'r') as f:
        return json.load(f)


def json_output(data):
    return json.dumps(data, sort_keys=False, separators=(',', ':'), ensure_ascii=False)


def output(target_path, data, if_not_exists=False):
    if if_not_exists and os.path.exists(target_path):
        return

    with open(target_path, 'w') as f:
        f.write(json_output(data))


def mkdir(_path):
    if not os.path.exists(_path):
        os.makedirs(_path)


def url_to_base64(url):
    import base64
    import requests as req
    from io import BytesIO

    if os.path.isfile(url):
        f = open(url, 'rb')
        img_data_b64 = base64.b64encode(f.read())
        f.close()
    else:
        response = req.get(url)
        img_data_b64 = base64.b64encode(BytesIO(response.content).read())

    return bytes.decode(img_data_b64)


def get_cookies(raw_cookies: str):
    from http.cookies import SimpleCookie
    cookie = SimpleCookie()
    cookie.load(raw_cookies)

    # Even though SimpleCookie is dictionary-like, it internally uses a Morsel object
    # which is incompatible with requests. Manually construct a dictionary instead.
    cookies = {k: v.value for k, v in cookie.items()}

    return cookies


def read_xls(xls_file_path: str):
    import xlrd
    data = xlrd.open_workbook(xls_file_path)
    table = data.sheets()[0]
    nrows = table.nrows

    for i in range(1, nrows):
        yield table.row_values(i)


def frozen_fallback(runs, frozen_start_timestamp):
    for r in runs:
        if r['timestamp'] >= frozen_start_timestamp:
            r['status'] = 'pending'

    return runs


def get_timestamp(dt):
    timeArray = time.strptime(dt, "%Y-%m-%d %H:%M:%S")
    timestamp = time.mktime(timeArray)
    return int(timestamp)


def generate_problem_id(problem_nums: int) -> typing.List[str]:
    return [chr(ord('A') + i) for i in range(problem_nums)]


def generate_balloon_color(problem_nums: int) -> typing.List[config.Color]:
    default_balloon_color_list = [
        config.Color('rgba(189, 14, 14, 0.7)', '#fff'),
        config.Color('rgba(255, 144, 228, 0.7)', '#fff'),
        config.Color('rgba(255, 255, 255, 0.7)', '#000'),
        config.Color('rgba(38, 185, 60, 0.7)', '#fff'),
        config.Color('rgba(239, 217, 9, 0.7)', '#000'),
        config.Color('rgba(243, 88, 20, 0.7)', '#fff'),
        config.Color('rgba(12, 76, 138, 0.7)', '#fff'),
        config.Color('rgba(156, 155, 155, 0.7)', '#fff'),
        config.Color('rgba(4, 154, 115, 0.7)', '#fff'),
        config.Color('rgba(159, 19, 236, 0.7)', '#fff'),
        config.Color('rgba(42, 197, 202, 0.7)', '#fff'),
        config.Color('rgba(142, 56, 54, 0.7)', '#fff'),
        config.Color('rgba(0, 0, 0, 0.7)', '#fff'),
    ]

    return default_balloon_color_list[:problem_nums]
